@@ -664,15 +664,15 @@ class CameraDevice(Protocol):
     ) -> None: ...
     async def get_value(
         self, state_name: str
-    ) -> (
-        LightState
-        | MotionState
-        | AudioState
-        | ObjectState
-        | DoorbellState
-        | SirenState
-        | BatteryState
-    ): ...
+    ) -> Union[
+        LightState,
+        MotionState,
+        AudioState,
+        ObjectState,
+        DoorbellState,
+        SirenState,
+        BatteryState,
+    ]: ...
 
     @overload
     async def update_state(
